@@ -51,7 +51,7 @@ class SentinelHubBatch(SentinelHubService):
         :param output: A dictionary with output parameters. It can be built with `output` method. Alternatively, one
             can set `bucket_name` parameter instead.
         :type output: dict or None
-        :param bucket_name: A name of an s3 bucket where to save data. Alternatively, one can set `output` parameter
+        :param bucket_name: A name of an S3 bucket where to save data. Alternatively, one can set `output` parameter
             to specify more output parameters.
         :type bucket_name: str or None
         :param description: A description of a batch request
@@ -455,28 +455,28 @@ class SentinelHubBatch(SentinelHubService):
         return self.client.get_json(url=job_url, request_type=RequestType.POST, use_session=True)
 
     def _get_process_url(self, request_id=None):
-        """Creates an URL for process endpoint"""
+        """Creates a URL for process endpoint"""
         url = f"{self.service_url}/process"
         if request_id:
             return f"{url}/{request_id}"
         return url
 
     def _get_tiles_url(self, request_id, tile_id=None):
-        """Creates an URL for tiles endpoint"""
+        """Creates a URL for tiles endpoint"""
         url = f"{self._get_process_url(request_id)}/tiles"
         if tile_id:
             return f"{url}/{tile_id}"
         return url
 
     def _get_tiling_grids_url(self, grid_id=None):
-        """Creates an URL for tiling grids endpoint"""
+        """Creates a URL for tiling grids endpoint"""
         url = f"{self.service_url}/tilinggrids"
         if grid_id:
             return f"{url}/{grid_id}"
         return url
 
     def _get_collections_url(self, collection_id=None):
-        """Creates an URL for batch collections endpoint"""
+        """Creates a URL for batch collections endpoint"""
         url = f"{self.service_url}/collections"
         if collection_id:
             return f"{url}/{collection_id}"
@@ -554,20 +554,20 @@ class BatchRequest:
 
     request_id: str = field(metadata=dataclass_config(field_name="id"))
     process_request: dict
+    tile_count: int
+    status: BatchRequestStatus = field(metadata=enum_config(BatchRequestStatus))
     other_data: CatchAll
     user_id: Optional[str] = None
     created: Optional[dt.datetime] = field(metadata=datetime_config, default=None)
-    tiling_grid: Optional[dict] = None
-    output: Optional[dict] = None
+    tiling_grid: dict = field(default_factory=dict)
+    output: dict = field(default_factory=dict)
     bucket_name: Optional[str] = None
     description: Optional[str] = None
     value_estimate: Optional[float] = None
-    tile_count: Optional[int] = None
     tile_width_px: Optional[int] = None
     tile_height_px: Optional[int] = None
     user_action: Optional[BatchUserAction] = field(metadata=enum_config(BatchUserAction), default=None)
     user_action_updated: Optional[str] = field(metadata=datetime_config, default=None)
-    status: Optional[BatchRequestStatus] = field(metadata=enum_config(BatchRequestStatus), default=None)
     error: Optional[str] = None
 
     _REPR_PARAM_NAMES = [
@@ -675,10 +675,14 @@ class BatchCollection(BaseCollection):
 
 
 _MIN_SLEEP_TIME = 60
+_DEFAULT_SLEEP_TIME = 120
 _MIN_ANALYSIS_SLEEP_TIME = 5
+_DEFAULT_ANALYSIS_SLEEP_TIME = 10
 
 
-def monitor_batch_job(batch_request, config, sleep_time=120, analysis_sleep_time=10):
+def monitor_batch_job(
+    batch_request, config, sleep_time=_DEFAULT_SLEEP_TIME, analysis_sleep_time=_DEFAULT_ANALYSIS_SLEEP_TIME
+):
     """A utility function that keeps checking for number of processed tiles until the given batch request finishes.
     During the process it shows a progress bar and at the end it reports information about finished and failed tiles.
 
@@ -688,7 +692,7 @@ def monitor_batch_job(batch_request, config, sleep_time=120, analysis_sleep_time
         case a batch job is still being analysed this function will wait until the analysis ends.
       - This function will be continuously collecting tile information from Sentinel Hub service. To avoid making too
         many requests please make sure to adjust `sleep_time` parameter according to the size of your job. Larger jobs
-        don't need too frequent tile status updates.
+        don't need very frequent tile status updates.
       - Some information about the progress of this function is reported to logging level INFO.
 
     :param batch_request: An object with information about a batch request. Alternatively, it could only be a batch
@@ -707,27 +711,13 @@ def monitor_batch_job(batch_request, config, sleep_time=120, analysis_sleep_time
     """
     if sleep_time < _MIN_SLEEP_TIME:
         raise ValueError(f"To avoid making too many service requests please set sleep_time>={_MIN_SLEEP_TIME}")
-    if analysis_sleep_time < _MIN_ANALYSIS_SLEEP_TIME:
-        raise ValueError(
-            f"To avoid making too many service requests please set analysis_sleep_time>={_MIN_ANALYSIS_SLEEP_TIME}"
-        )
-
-    batch_client = SentinelHubBatch(config=config)
-
-    batch_request = batch_client.get_request(batch_request)
-    while batch_request.status in [BatchRequestStatus.CREATED, BatchRequestStatus.ANALYSING]:
-        LOGGER.info(
-            "Batch job has a status %s, sleeping for %d seconds", batch_request.status.value, analysis_sleep_time
-        )
-        time.sleep(analysis_sleep_time)
-
-        batch_request = batch_client.get_request(batch_request)
-
-    batch_request.raise_for_status(status=[BatchRequestStatus.FAILED, BatchRequestStatus.CANCELED])
 
+    batch_request = monitor_batch_analysis(batch_request, config, sleep_time=analysis_sleep_time)
     if batch_request.status is BatchRequestStatus.PROCESSING:
         LOGGER.info("Batch job is running")
 
+    batch_client = SentinelHubBatch(config=config)
+
     tiles_per_status = _get_batch_tiles_per_status(batch_request, batch_client)
     success_count = len(tiles_per_status[BatchTileStatus.PROCESSED])
     finished_count = success_count + len(tiles_per_status[BatchTileStatus.FAILED])
@@ -757,6 +747,39 @@ def monitor_batch_job(batch_request, config, sleep_time=120, analysis_sleep_time
     return tiles_per_status
 
 
+def monitor_batch_analysis(batch_request, config, sleep_time=_DEFAULT_ANALYSIS_SLEEP_TIME):
+    """A utility function that is waiting until analysis phase of a batch job finishes and regularly checks its status.
+    In case analysis phase failed it raises an error at the end.
+
+    :param batch_request: An object with information about a batch request. Alternatively, it could only be a batch
+        request id or a payload.
+    :type batch_request: BatchRequest or dict or str
+    :param config: A configuration object with required parameters `sh_client_id`, `sh_client_secret`, and
+        `sh_auth_base_url` which is used for authentication and `sh_base_url` which defines the service deployment
+        where Batch API will be called.
+    :type config: SHConfig
+    :param sleep_time: Number of seconds between consecutive status updates during analysis phase.
+    :type sleep_time: int
+    :return: Batch request info
+    :rtype: BatchRequest
+    """
+    if sleep_time < _MIN_ANALYSIS_SLEEP_TIME:
+        raise ValueError(
+            f"To avoid making too many service requests please set analysis sleep time >={_MIN_ANALYSIS_SLEEP_TIME}"
+        )
+
+    batch_client = SentinelHubBatch(config=config)
+
+    batch_request = batch_client.get_request(batch_request)
+    while batch_request.status in [BatchRequestStatus.CREATED, BatchRequestStatus.ANALYSING]:
+        LOGGER.info("Batch job has a status %s, sleeping for %d seconds", batch_request.status.value, sleep_time)
+        time.sleep(sleep_time)
+        batch_request = batch_client.get_request(batch_request)
+
+    batch_request.raise_for_status(status=[BatchRequestStatus.FAILED, BatchRequestStatus.CANCELED])
+    return batch_request
+
+
 def _get_batch_tiles_per_status(batch_request, batch_client):
     """A helper function that queries information about batch tiles and returns information about tiles, grouped by
     tile status.
