@@ -123,7 +123,7 @@ class AreaSplitter(ABC):
             be the default CRS of the splitter.
         :type crs: CRS or None
         :param buffer: A percentage of each BBox size increase. This will cause neighbouring bounding boxes to overlap.
-        :type buffer: float or None
+        :type buffer: (float, float) or float or None
         :param reduce_bbox_sizes: If `True` it will reduce the sizes of bounding boxes so that they will tightly
             fit the given geometry in `shape_list`. This overrides the same parameter from constructor
         :type reduce_bbox_sizes: bool
@@ -132,7 +132,7 @@ class AreaSplitter(ABC):
         """
         bbox_list = self.bbox_list
         if buffer:
-            bbox_list = [bbox.buffer(buffer) for bbox in bbox_list]
+            bbox_list = [bbox.buffer(buffer, relative=True) for bbox in bbox_list]
 
         if reduce_bbox_sizes is None:
             reduce_bbox_sizes = self.reduce_bbox_sizes
@@ -179,11 +179,11 @@ class AreaSplitter(ABC):
         :rtype: BBox
         """
         bbox_list = [BBox(shape.bounds, crs=self.crs) for shape in self.shape_list]
-        area_minx = min([bbox.lower_left[0] for bbox in bbox_list])
-        area_miny = min([bbox.lower_left[1] for bbox in bbox_list])
-        area_maxx = max([bbox.upper_right[0] for bbox in bbox_list])
-        area_maxy = max([bbox.upper_right[1] for bbox in bbox_list])
-        bbox = BBox([area_minx, area_miny, area_maxx, area_maxy], crs=self.crs)
+        area_min_x = min([bbox.lower_left[0] for bbox in bbox_list])
+        area_min_y = min([bbox.lower_left[1] for bbox in bbox_list])
+        area_max_x = max([bbox.upper_right[0] for bbox in bbox_list])
+        area_max_y = max([bbox.upper_right[1] for bbox in bbox_list])
+        bbox = BBox([area_min_x, area_min_y, area_max_x, area_max_y], crs=self.crs)
         if crs is None:
             return bbox
         return bbox.transform(crs)
@@ -614,7 +614,7 @@ class BaseUtmSplitter(AreaSplitter):
         bounding boxes
 
         :param buffer: A percentage of each BBox size increase. This will cause neighbouring bounding boxes to overlap.
-        :type buffer: float or None
+        :type buffer: (float, float) or float or None
         :return: List of bounding boxes
         :rtype: list(BBox)
         """
@@ -661,7 +661,7 @@ class UtmZoneSplitter(BaseUtmSplitter):
     def _get_utm_polygons(self):
         """Find UTM zones overlapping with input area shape
 
-        The returned geometry corresponds to the a triangle ranging from the equator to the north/south pole
+        The returned geometry corresponds to a triangle ranging from the equator to the North/South Pole
 
         :return: List of geometries and properties of UTM zones overlapping with input area shape
         :rtype: list
