@@ -17,7 +17,7 @@ from .exceptions import SHUserWarning
 
 
 class PackageProps:
-    """Class for obtaining package properties. Currently it supports obtaining package version."""
+    """Class for obtaining package properties. Currently, it supports obtaining package version."""
 
     @staticmethod
     def get_version():
@@ -54,6 +54,32 @@ class ServiceType(Enum):
     PROCESSING_API = "processing"
 
 
+class ResamplingTypeMeta(EnumMeta):
+    """Metaclass for ResamplingType so that it is not case sensitive."""
+
+    def __call__(cls, value, *args, **kwargs):
+        if isinstance(value, str):
+            value = value.upper()
+
+        return super().__call__(value, *args, **kwargs)
+
+
+class ResamplingType(Enum, metaclass=ResamplingTypeMeta):
+    """Enum constant class for type of resampling."""
+
+    NEAREST = "NEAREST"
+    BILINEAR = "BILINEAR"
+    BICUBIC = "BICUBIC"
+
+
+class MosaickingOrder(Enum):
+    """Enum constant class for type of mosaicking order."""
+
+    MOST_RECENT = "mostRecent"
+    LEAST_RECENT = "leastRecent"
+    LEAST_CC = "leastCC"
+
+
 class CRSMeta(EnumMeta):
     """Metaclass used for building CRS Enum class"""
 
@@ -172,9 +198,9 @@ class CRS(Enum, metaclass=CRSMeta):
 
     @property
     def opengis_string(self):
-        """Returns an URL to OGC webpage where the CRS is defined
+        """Returns a URL to OGC webpage where the CRS is defined
 
-        :return: An URL with CRS definition
+        :return: A URL with CRS definition
         :rtype: str
         """
         return f"http://www.opengis.net/def/crs/EPSG/0/{self.epsg}"
@@ -189,31 +215,37 @@ class CRS(Enum, metaclass=CRSMeta):
         """
         return self.name.startswith("UTM")
 
-    @functools.lru_cache(maxsize=5)
+    @functools.lru_cache(maxsize=128)
     def projection(self):
-        """Returns a projection in form of pyproj class. For better time performance it will cache results of
-        5 most recently used CRS classes.
+        """Returns a projection in form of pyproj class.
+
+        For better time performance this method will cache `128` most recent results. Cache can be released with
+        `CRS.projection.cache_clear()`.
 
         :return: pyproj projection class
         :rtype: pyproj.Proj
         """
         return pyproj.Proj(self._get_pyproj_projection_def(), preserve_units=True)
 
-    @functools.lru_cache(maxsize=5)
+    @functools.lru_cache(maxsize=128)
     def pyproj_crs(self):
-        """Returns a pyproj CRS class. For better time performance it will cache results of
-        5 most recently used CRS classes.
+        """Returns a pyproj CRS class.
+
+        For better time performance this method will cache `128` most recent results. Cache can be released with
+        `CRS.pyproj_crs.cache_clear()`.
 
         :return: pyproj CRS class
         :rtype: pyproj.CRS
         """
         return pyproj.CRS(self._get_pyproj_projection_def())
 
-    @functools.lru_cache(maxsize=10)
+    @functools.lru_cache(maxsize=512)
     def get_transform_function(self, other, always_xy=True):
         """Returns a function for transforming geometrical objects from one CRS to another. The function will support
         transformations between any objects that pyproj supports.
-        For better time performance this method will cache results of 10 most recently used pairs of CRS classes.
+
+        For better time performance this method will cache results. Cache can be released with
+        `CRS.get_transform_function.cache_clear()`.
 
         :param self: Initial CRS
         :type self: CRS
