@@ -2,8 +2,8 @@
 A download part of the package
 """
 
-from .request import DownloadRequest
 from .client import DownloadClient
+from .request import DownloadRequest
 from .sentinelhub_client import SentinelHubDownloadClient
 from .sentinelhub_statistical_client import SentinelHubStatisticalDownloadClient
-from .aws_client import AwsDownloadClient
+from .session import SentinelHubSession
