@@ -35,7 +35,7 @@ class DownloadClient:
 
     def __init__(self, *, redownload=False, raise_download_errors=True, config=None):
         """
-        :param redownload: If `True` the data will always be downloaded again. By default this is set to `False` and
+        :param redownload: If `True` the data will always be downloaded again. By default, this is set to `False` and
             the data that has already been downloaded and saved to an expected location will be read from the
             location instead of being downloaded again.
         :type redownload: bool
@@ -69,22 +69,23 @@ class DownloadClient:
         if is_single_request:
             download_requests = [download_requests]
 
+        data_list = [None] * len(download_requests)
+
         with ThreadPoolExecutor(max_workers=max_threads) as executor:
             download_list = [
                 executor.submit(self._single_download, request, decode_data) for request in download_requests
             ]
             future_order = {future: i for i, future in enumerate(download_list)}
 
-        data_list = [None] * len(download_list)
-        # Consider using tqdm.contrib.concurrent.thread_map in the future
-        if show_progress:
-            with tqdm(total=len(download_list)) as pbar:
+            # Consider using tqdm.contrib.concurrent.thread_map in the future
+            if show_progress:
+                with tqdm(total=len(download_list)) as pbar:
+                    for future in as_completed(download_list):
+                        data_list[future_order[future]] = self._process_download_future(future)
+                        pbar.update(1)
+            else:
                 for future in as_completed(download_list):
                     data_list[future_order[future]] = self._process_download_future(future)
-                    pbar.update(1)
-        else:
-            for future in as_completed(download_list):
-                data_list[future_order[future]] = self._process_download_future(future)
 
         if is_single_request:
             return data_list[0]
@@ -185,7 +186,7 @@ class DownloadClient:
     def get_json(self, url, post_values=None, headers=None, request_type=None, **kwargs):
         """Download request as JSON data type
 
-        :param url: An URL from where the data will be downloaded
+        :param url: A URL from where the data will be downloaded
         :type url: str
         :param post_values: A dictionary of parameters for a POST request
         :type post_values: dict or None
