@@ -34,12 +34,12 @@ class BaseGeometry(ABC):
     @property
     @abstractmethod
     def geometry(self):
-        """An abstract property - ever subclass must implement geometry property"""
+        """An abstract property - every subclass must implement geometry property"""
         raise NotImplementedError
 
     @property
     def geojson(self):
-        """Returns representation in a GeoJSON format. Use json.dump for writing it to file.
+        """Returns representation in a GeoJSON format. Use `json.dump` for writing it to file.
 
         :return: A dictionary in GeoJSON format
         :rtype: dict
@@ -47,7 +47,7 @@ class BaseGeometry(ABC):
         return self.get_geojson(with_crs=True)
 
     def get_geojson(self, with_crs=True):
-        """Returns representation in a GeoJSON format. Use json.dump for writing it to file.
+        """Returns representation in a GeoJSON format. Use `json.dump` for writing it to file.
 
         :param with_crs: A flag indicating if GeoJSON dictionary should contain CRS part
         :type with_crs: bool
@@ -92,9 +92,9 @@ class BBox(BaseGeometry):
 
     Note that BBox coordinate system depends on ``crs`` parameter:
 
-    - In case of ``constants.CRS.WGS84`` axis x represents longitude and axis y represents latitude
-    - In case of ``constants.CRS.POP_WEB`` axis x represents easting and axis y represents northing
-    - In case of ``constants.CRS.UTM_*`` axis x represents easting and axis y represents northing
+    - In case of ``constants.CRS.WGS84`` axis x represents longitude and axis y represents latitude.
+    - In case of ``constants.CRS.POP_WEB`` axis x represents easting and axis y represents northing.
+    - In case of ``constants.CRS.UTM_*`` axis x represents easting and axis y represents northing.
     """
 
     def __init__(self, bbox, crs):
@@ -207,7 +207,7 @@ class BBox(BaseGeometry):
 
         This transformation will transform the bounding box geometry to another CRS as a geometric object, and then
         define a new bounding box from boundaries of that geometry. The resulting bounding box might be larger than
-        original bounding box but it will always completely cover it.
+        original bounding box, but it will always completely cover it.
 
         :param crs: target CRS
         :type crs: constants.CRS
@@ -221,25 +221,45 @@ class BBox(BaseGeometry):
         bbox_geometry = bbox_geometry.transform(crs, always_xy=always_xy)
         return bbox_geometry.bbox
 
-    def buffer(self, buffer):
-        """Changes both BBox dimensions (width and height) by a percentage of size of each dimension. If number is
-        negative, the size will decrease. Returns a new instance of BBox object.
+    def buffer(self, buffer, *, relative=True):
+        """Provides a new bounding box with a size that is changed either by a relative or an absolute buffer.
 
-        :param buffer: A percentage of BBox size change
-        :type buffer: float
-        :return: A new bounding box of buffered size
+        :param buffer: The buffer can be provided either as a single number or a tuple of 2 numbers, one for buffer in
+            horizontal direction and one for buffer in vertical direction. The buffer can also be negative as long as
+            this doesn't reduce the bounding box into nothing.
+        :type buffer: (float, float) or float or None
+        :param relative: If `True` the given buffer values will be interpreted as a percentage of distance between
+            bounding box center point and its side edge (not to distance between opposite sides!). If `False` the given
+            buffer will be interpreted as an absolute buffer measured in bounding box coordinate units.
+        :type relative: bool
+        :return: A new bounding box of buffered size.
         :rtype: BBox
         """
-        if buffer < -1:
-            raise ValueError("Cannot reduce the bounding box to nothing, buffer must be >= -1.0")
-        ratio = 1 + buffer
-        mid_x, mid_y = self.middle
+        if isinstance(buffer, tuple):
+            buffer_x, buffer_y = buffer
+        elif isinstance(buffer, (int, float)):
+            buffer_x, buffer_y = buffer, buffer
+        else:
+            raise ValueError(f"Buffer should be a number or a tuple of 2 numbers, got {type(buffer)}")
+
+        size_x, size_y = self.max_x - self.min_x, self.max_y - self.min_y
+
+        if relative:
+            buffer_x = buffer_x * size_x / 2
+            buffer_y = buffer_y * size_y / 2
+
+        for absolute_buffer, size, direction in [(buffer_x, size_x, "horizontal"), (buffer_y, size_y, "vertical")]:
+            if 2 * absolute_buffer + size <= 0:
+                raise ValueError(
+                    f"Negative buffer is too large, cannot reduce the bounding box to nothing in {direction} direction"
+                )
+
         return BBox(
             (
-                mid_x - (mid_x - self.min_x) * ratio,
-                mid_y - (mid_y - self.min_y) * ratio,
-                mid_x + (self.max_x - mid_x) * ratio,
-                mid_y + (self.max_y - mid_y) * ratio,
+                self.min_x - buffer_x,
+                self.min_y - buffer_y,
+                self.max_x + buffer_x,
+                self.max_y + buffer_y,
             ),
             self.crs,
         )
@@ -407,7 +427,7 @@ class Geometry(BaseGeometry):
     """A class that combines shapely geometry with coordinate reference system. It currently supports polygons and
     multipolygons.
 
-    It can be initialize with any of the following geometry representations:
+    It can be initialized with any of the following geometry representations:
     - `shapely.geometry.Polygon` or `shapely.geometry.MultiPolygon`
     - A GeoJSON dictionary with (multi)polygon coordinates
     - A WKT string with (multi)polygon coordinates
